@@ -93,7 +93,7 @@ module.exports = generators.Base.extend({
       this.appName = mout.string.pascalCase(this.appName);
       this.appId = this.options.appId || 'com.example.' + this.appName;
       this.appPath = 'app';
-      this.jsPath = 'js';
+      this.jsPath = this.appPath+'/js';
       this.ctrlPath = this.jsPath + '/controllers/';
       this.servicesPath = this.jsPath + '/services/';
       this.modelsPath = this.servicesPath + 'models/';
@@ -118,6 +118,12 @@ module.exports = generators.Base.extend({
       // directory into your users new application path
       this.sourceRoot(path.join(__dirname, '../templates/'));
       this.directory('common/root', '.', true);
+      // create module.js
+      var moduleFile = this.readFileAsString(path.join(__dirname, 'scripts/module.js'))
+      moduleFile = moduleFile.replace(new RegExp("{{APP_NAME}}", 'g'), this.appName);
+      var moduleFilePath = this.jsPath + 'modules.js'
+      this.write(ctrlFilePath, moduleFile);
+      this.scriptsFile.push(moduleFilePath);
     },
 
     packageFiles: function packageFiles() {
@@ -138,15 +144,8 @@ module.exports = generators.Base.extend({
         } else {
           console.log(chalk.yellow('Created a new Cordova project with name "' + this.appName + '" and id "' + this.appId + '"'));
           mkdir.sync('local_plugins');
-          this.copy('scripts/modules.js', this.jsPath + 'modules.js');
-          this.scriptsFile.push(this.jsPath + 'modules.js');
-
-          // create module.js
-          var moduleFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/module.js'))
-          moduleFile = moduleFile.replace(new RegExp("{{APP_NAME}}", 'g'), this.appName);
-          var moduleFilePath = this.jsPath + 'modules.js'
-          this.write(ctrlFilePath, moduleFile);
-          this.scriptsFile.push(moduleFilePath);
+        
+          
         }
         done();
       }.bind(this));
@@ -222,7 +221,7 @@ module.exports = generators.Base.extend({
        // Regex: User scripts (scripts.js)
        var scripts = '';
        for (var i = this.scriptsFile.length - 1; i >= 0; i--) {
-         scripts += "<script src=\"" + this.scriptsFile[i] + "\"><\/script>\n";
+         scripts += "\t<script src=\"" + this.scriptsFile[i] + "\"><\/script>\n";
        };
        this.indexFile = this.indexFile.replace(/<!-- your app's js -->/g,"<!-- your app's js -->\n    <!-- build:js scripts\/scripts.js -->");
        this.indexFile = this.indexFile.replace(/<\/head>/g, scripts + "    <!-- endbuild -->\n  <\/head>");
@@ -232,6 +231,7 @@ module.exports = generators.Base.extend({
        
        // Regex/Rename: Scripts path (Ionics 'js' to 'scripts')
        this.indexFile = this.indexFile.replace(new RegExp("src=\"js", 'g'), "src=\"scripts");
+       this.indexFile = this.indexFile.replace(new RegExp("src=\"app/js", 'g'), "src=\"scripts");
 
        // Write index.html
        this.indexFile = this.indexFile.replace(/&apos;/g, "'");
