@@ -4,9 +4,11 @@ var path = require('path');
 var createService = function(self, provider) {
   var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
   file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
-  var filePath = path.join(self.servicePath, provider+'Service.js');
+  var fileName = provider+'Service.js';
+  var filePath = path.join(self.servicesPath, fileName);
   self.write(filePath, file);
   self.scriptsFile.push(filePath);
+  return provider+'Service';
 }
 
 var prompt = [{
@@ -42,14 +44,21 @@ module.exports = {
   install: function(self) {
     var choices = self.auth;
     if (choices) {
+      var serviceDependencies = '';
+      var qServiceDependencies = '';
       var done = self.async();
       for (var i = choices.length - 1; i >= 0; i--) {
         console.log('Choice:' + choices[i]);
-        createService(self, choices[i]);
+        var serviceName = createService(self, choices[i]);
+        serviceDependencies += ', ' + serviceName;
+        qServiceDependencies += '\'' + serviceName + '\',\n';
       };
+
       var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/AuthService.js'))
       file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
-      var filePath = path.join(self.servicePath, 'AuthService.js');
+      file = file.replace(new RegExp("{{AUTH_PROVIDERS_QUOTED}}", 'g'), qServiceDependencies);  
+      file = file.replace(new RegExp("{{AUTH_PROVIDERS}}", 'g'), self.appName);  
+      var filePath = path.join(self.servicesPath, 'AuthService.js');
       self.write(filePath, file);
       self.scriptsFile.push(filePath);
       done();      
