@@ -29,6 +29,11 @@ module.exports = {
         }, function(client_id) {
           self.directory('../templates/plugins/com.plugins.parsePushNotifications', 'local_plugins/com.plugins.parsePushNotifications');
           self.lplugins.push('local_plugins/com.plugins.parsePushNotifications --variable APP_ID=' + app_id + ' --variable CLIENT_ID=' + client_id);
+          var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/PushNotificationService.js'))
+          file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
+          var filePath = path.join(self.servicesPath, 'PushNotificationService.js');
+          self.write(filePath, file);
+          self.scriptsFile.push(filePath);
           done();
         });
       });
