@@ -56,9 +56,9 @@ var generateConfigRoute = function(self, route) {
   var ctrl = camelCase(route.state) + 'Ctrl';
   var view = camelCase(route.state);
   var configRoute = 
-    "\t.state(\'"+ route.state +"\', {\n" +
+    ".state(\'"+ route.state +"\', {\n" +
     "\t\turl: \'" + route.url + "',\n" +
-    "\t\ttemplateUrl: \'templates/" + view + ".html\'\n,"+
+    "\t\ttemplateUrl: \'templates/" + view + ".html\',\n"+
     "\t\tcontroller: \'" + ctrl +".js\',\n" +
     "\t\tabstract: " + route.abstract + ",\n" +
     "\t})";
@@ -94,7 +94,7 @@ module.exports = {
     var done = self.async();
     var configRoutes = '';
     if (routes.length > 0) {
-      configRoutes = '$stateProvider\n';
+      configRoutes = '$stateProvider\n\t';
     }
     for (var i = routes.length - 1; i >= 0; i--) {
       console.log('Installing route:' + routes[i].state);
